@@ -2,8 +2,9 @@
 
 """mesh_sync provides entry point main()."""
 
-__version__ = "1.0.5"
+__version__ = "1.0.6"
 
+import argparse
 import base64
 import re
 import sys
@@ -158,6 +159,14 @@ def get_all_files(auth_token: str, tree_url, repo_url):
 
 
 def main():
+    # Parse the command line arguments
+    parser = argparse.ArgumentParser(description='Downloads the latest version of the update files from the github repo')
+    parser.add_argument('-p', help='Project ID', required=False)
+
+    args = parser.parse_args()
+    project_id = args.p
+    print("Project ID: %s" % project_id)
+
     try:
         token = input("Enter your GitHub token: ")
 
@@ -169,11 +178,23 @@ def main():
                 print(">> Found git url: %s" % git_url)
                 get_update_file(auth_token=token, repo_url=git_url)
         else:
+
             print(">> Could not find .git url")
-            git_url_input = input("Please enter the [Project ID] that was given to you: ")
+            if project_id is None:
+                git_url_input = input("Please enter the [Project ID] that was given to you: ")
+            else:
+                git_url_input = project_id
+
             git_url_input = git_url_input.rstrip('/')
+
             # Remove spaces from all the sides of the string
             git_url_input = git_url_input.strip()
+
+            if '/' not in git_url_input:
+
+                # Single Project ID given, add prefix 'MeshMonitors-Remote-1/'
+                git_url_input = f"MeshMonitors-Remote-1/{git_url_input}"
+
             if git_url_input is not None:
                 is_empty = os.listdir(os.getcwd()) == []
                 if is_empty:
